==> ocstore25_6_20.zip: OcStore/Entity/MenuCursor.h <==
#pragma once
#include "GameInput.h"
#include "Entity.h"
#define MENUCURSOR_CREATENAME L"menu_cursor"
//˵
class MenuCursor :
	public Entity
{
public:
	MenuCursor();
	void Step() override;
	void SetState(int stateID, int lr) override;
private:
	int blockControl = 1;//ǰ0.5ֹ
	bool bInitFindEntity = true;
	int menu = 0;
	int index = 0;
	int index2 = 0;//浵ҳѡ
	int index3 = 0;//ƽ
	int index4 = 0;//ҳ±
	int slotPage = 0;//浵ǰҳ
	bool bOnce = false;
	bool bInitLanguage = true;
	int languageNum = 0;
	bool runCursor = false;
	int slideInterval = 0;//ʱ
	std::wstring saveName;//ѡϷĴ浵
	std::wstring gameName;//ѡϷ
	void InitLanguageMenu();
	void BlockFirstOkOp();
	void MainMenu();
	void OpMenu();
	void GraphMenu();
	void AudioMenu();
	void ControlMenu();
	void Player1Menu();
	void Player1KeyboardMenu();
	void Player1JoystickMenu();
	void Player2Menu();
	void Player2KeyboardMenu();
	void Player2JoystickMenu();
	void SelectControllerMenu();
	void LanguageMenu();
	void SlotMenu();
	void SelectModeMenu();
	std::weak_ptr<Entity> GetEntityByType(const wchar_t* name);
	void HideAllMenuLayer();
	void ShowMainMenu();
	void ShowOpMenu();
	void ShowGraphMenu();
	void ShowAudioMenu();
	void ShowControlMenu();
	void ShowPlayer1Menu();
	void ShowPlayer1KeyboardMenu();
	void ShowPlayer1JoystickMenu();
	void ShowPlayer2Menu();
	void ShowPlayer2KeyboardMenu();
	void ShowPlayer2JoystickMenu();
	void ShowSelectControllerMenu();
	void ShowLanguageMenu();
	void ShowSlotMenu();
	void ShowSelectModeMenu();
	bool opU = false;
	bool opD = false;
	bool opL = false;
	bool opR = false;
	bool opOk = false;
	bool opCancel = false;
	bool opMenu = false;
	bool opPageUp = false;
	bool opPageDown = false;
	void ClearOp();
	void GetOp();
	void UpdateSlotPage(bool bDrawSlot);
	bool SlotMenuSlideControl();
	std::weak_ptr<Entity> e_slotPageNum;
	std::weak_ptr<Entity> e_slotA;
	std::weak_ptr<Entity> e_slotB;
	std::weak_ptr<Entity> e_slotC;
	std::weak_ptr<Entity> e_slotA_RoomName;
	std::weak_ptr<Entity> e_slotB_RoomName;
	std::weak_ptr<Entity> e_slotC_RoomName;
	std::weak_ptr<Entity> e_slotA_p1Icon;
	std::weak_ptr<Entity> e_slotA_p2Icon;
	std::weak_ptr<Entity> e_slotB_p1Icon;
	std::weak_ptr<Entity> e_slotB_p2Icon;
	std::weak_ptr<Entity> e_slotC_p1Icon;
	std::weak_ptr<Entity> e_slotC_p2Icon;
	int difficulty = 1;//0 1ͨ 2
};

std::shared_ptr<Entity> CreateMenuCursor();

==> ocstore25_7_4.zip: OcStore/Entity/MenuCursor.h <==
#pragma once
#include "GameInput.h"
#include "Entity.h"
#define MENUCURSOR_CREATENAME L"menu_cursor"
//˵
class MenuCursor :
	public Entity
{
public:
	MenuCursor();
	void Step() override;
	void SetState(int stateID, int lr) override;
private:
	int blockControl = 1;//ǰ0.5ֹ
	bool bInitFindEntity = true;
	int menu = 0;
	int index = 0;
	int index2 = 0;//浵ҳѡ
	int index3 = 0;//ƽ
	int index4 = 0;//ҳ±
	int slotPage = 0;//浵ǰҳ
	bool bOnce = false;
	bool bInitLanguage = true;
	int languageNum = 0;
	bool runCursor = false;
	int slideInterval = 0;//ʱ
	std::wstring saveName;//ѡϷĴ浵
	std::wstring gameName;//ѡϷ
	void InitLanguageMenu();
	void BlockFirstOkOp();
	void MainMenu();
	void OpMenu();
	void GraphMenu();
	void AudioMenu();
	void ControlMenu();
	void Player1Menu();
	void Player1KeyboardMenu();
	void Player1JoystickMenu();
	void Player2Menu();
	void Player2KeyboardMenu();
	void Player2JoystickMenu();
	void SelectControllerMenu();
	void LanguageMenu();
	void SlotMenu();
	void SelectModeMenu();
	std::weak_ptr<Entity> GetEntityByType(const wchar_t* name);
	void HideAllMenuLayer();
	void ShowMainMenu();
	void ShowOpMenu();
	void ShowGraphMenu();
	void ShowAudioMenu();
	void ShowControlMenu();
	void ShowPlayer1Menu();
	void ShowPlayer1KeyboardMenu();
	void ShowPlayer1JoystickMenu();
	void ShowPlayer2Menu();
	void ShowPlayer2KeyboardMenu();
	void ShowPlayer2JoystickMenu();
	void ShowSelectControllerMenu();
	void ShowLanguageMenu();
	void ShowSlotMenu();
	void ShowSelectModeMenu();
	bool opU = false;
	bool opD = false;
	bool opL = false;
	bool opR = false;
	bool opOk = false;
	bool opCancel = false;
	bool opMenu = false;
	bool opPageUp = false;
	bool opPageDown = false;
	void ClearOp();
	void GetOp();
	void UpdateSlotPage(bool bDrawSlot);
	bool SlotMenuSlideControl();
	std::weak_ptr<Entity> e_slotPageNum;
	std::weak_ptr<Entity> e_slotA;
	std::weak_ptr<Entity> e_slotB;
	std::weak_ptr<Entity> e_slotC;
	std::weak_ptr<Entity> e_slotA_RoomName;
	std::weak_ptr<Entity> e_slotB_RoomName;
	std::weak_ptr<Entity> e_slotC_RoomName;
	std::weak_ptr<Entity> e_slotA_GameDifficulty;
	std::weak_ptr<Entity> e_slotB_GameDifficulty;
	std::weak_ptr<Entity> e_slotC_GameDifficulty;
	std::weak_ptr<Entity> e_slotA_p1Icon;
	std::weak_ptr<Entity> e_slotA_p2Icon;
	std::weak_ptr<Entity> e_slotB_p1Icon;
	std::weak_ptr<Entity> e_slotB_p2Icon;
	std::weak_ptr<Entity> e_slotC_p1Icon;
	std::weak_ptr<Entity> e_slotC_p2Icon;
	std::weak_ptr<Entity> e_normalMode;
	int difficulty = 0;//0 1ͨ 2
	void UpdateDifficulty();
};

std::shared_ptr<Entity> CreateMenuCursor();
